<!--
 * @Descripttion:
 * @version:
 * @Author: kBank
 * @Date: 2022-10-24 15:45:01
-->
<template>
  <div class="page">
    <topBar
      v-if="topList.length > 0"
      :topList="topList"
      :moren="moren"
    ></topBar>
    <div class="main">
      <el-form
        ref="select"
        :model="select"
        label-width="80px"
      >
        <el-row>
          <!-- 一层 -->
          <el-col :span="4">
            <el-form-item :label="'公告标题'">
              <el-input clearable v-model="select.title"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item :label="'显示类型'">
              <el-select
                clearable
                :placeholder="'请选择'"
                v-model="select.websiteType"
              >
                <el-option
                  v-for="item in webList"
                  :key="item.value"
                  :label="item.label"
                  :value="item.value"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item :label="'发布位置'">
              <el-select
                clearable
                :placeholder="'请选择'"
                v-model="select.publishLocation"
              >
                <el-option
                  v-for="item in localList"
                  :key="item.value"
                  :label="item.label"
                  :value="item.value"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item :label="'等级'">
              <el-select clearable :placeholder="'请选择'" v-model="select.grade">
                <el-option
                  v-for="item in gradeList"
                  :key="item.pkId"
                  :label="item.gradeName"
                  :value="item.pkId"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item :label="'强制弹窗'">
              <el-select
                clearable
                :placeholder="'请选择'"
                v-model="select.isPopScreen"
              >
                <el-option
                  v-for="item in popList"
                  :key="item.value"
                  :label="item.label"
                  :value="item.value"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item :label="'状态'">
              <el-select clearable :placeholder="'请选择'" v-model="select.state">
                <el-option
                  v-for="item in stateList"
                  :key="item.value"
                  :label="item.label"
                  :value="item.value"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item :label="'创建日期'">
              <el-date-picker
                v-model="creationTime"
                @change="changeTime"
                value-format="yyyy-MM-dd"
                type="daterange"
                :range-separator="'至'"
                :start-placeholder="'开始日期'"
                :end-placeholder="'结束日期'"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <!-- <el-col :span="8">
            <el-form-item :label="'生效日期'">
              <el-date-picker
                v-model="creationTime1"
                @change="changeTime1"
                value-format="yyyy-MM-dd"
                type="daterange"
                :range-separator="'至'"
                :start-placeholder="'开始日期'"
                :end-placeholder="'结束日期'"
              >
              </el-date-picker>
            </el-form-item>
          </el-col> -->
          <el-col :span="8">
            <el-form-item :label="'起止日期'">
              <el-date-picker
                v-model="creationTime2"
                @change="changeTime2"
                value-format="yyyy-MM-dd"
                type="daterange"
                :range-separator="'至'"
                :start-placeholder="'开始日期'"
                :end-placeholder="'结束日期'"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="4" style="margin-left: 10px">
            <el-button @click="getDataList" class="searchbtn"> {{ '搜索' }}</el-button>
            <el-button @click="reset"> {{ '重置' }}</el-button>
          </el-col>
        </el-row>
      </el-form>
      <div class="maintop">
        <div class="mainbtn">
          <el-button size="small" @click="openDig" class="thebtn1"
             v-has-buttons="['EmailedAdd']"
            >{{'添加'}}</el-button
          >
        </div>
      </div>
      <div class="maintable">
        <el-table
          :data="tableData"
          v-loading="loading"
          style="width: 100%"
          :header-cell-style="{ background: '#EEEEEE' }"
          :row-class-name="tableRowClassName"
          @selection-change="handleSelectionChange"
        >
          <el-table-column type="selection" width="55"> </el-table-column>
          <el-table-column align="center" prop="title" :label="'公告标题'">
          </el-table-column>
          <el-table-column
            align="center"
            prop="websiteTypeVal"
            :label="'显示类型'"
          >
          </el-table-column>
          <el-table-column
            align="center"
            prop="locationVOList"
            :label="'发布位置'"
          >
            <template slot-scope="scope">
              <div
                v-for="item in scope.row.locationVOList"
                :key="item.locationKey"
              >
                {{ item.locationKeyVal }}
              </div>
            </template>
          </el-table-column>
          <el-table-column align="center" prop="gradeVal" :label="'等级'">
            <template slot-scope="scope">
              <div
                v-for="item in scope.row.noticeGradeVOList"
                :key="item.gradeKey"
              >
                {{ item.gradeKeyVal }}
              </div>
            </template>
          </el-table-column>
          <el-table-column
            align="center"
            prop="isPopScreenVal"
            :label="'强制弹窗'"
          >
          </el-table-column>
          <el-table-column align="center" prop="stateVal" :label="'状态'">
          </el-table-column>
          <el-table-column align="center" prop="endTime" :label="'起止日期'">
          </el-table-column>
          <el-table-column align="center" prop="creationTime" :label="'创建日期'">
          </el-table-column>
          <el-table-column
            align="center"
            prop="time"
            :label="'操作'"
            fixed="right"
          >
            <template slot-scope="scope">
              <!-- <el-button
                @click="toFixed(scope.row.pkId)"
                type="text"
                size="small"
              >
                修改
              </el-button> -->
              <el-button
                @click="toFixed(scope.row.pkId)"
                type="text"
                size="small"
                v-has-buttons="['emailEdit']"
                style="color:#48B2FD"
              >
                {{ '查看' }}
              </el-button>
              <el-button v-if="scope.row.approveState == 1"
                @click="handleDelete(scope.row.pkId)"
                type="text"
                size="small"
                v-has-buttons="['emailDel']"
                style="color: #c73030"
              >
                {{ '删除' }}
              </el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>
    </div>
    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getDataList"
    />
    <el-dialog
      :title="'添加'"
      :close-on-click-modal="false"
      :visible.sync="dialogVisible"
      width="40%"
      center
      :before-close="handleClose"
    >
      <el-form ref="form" :rules="rules" :model="form" label-width="80px">
        <el-row>
          <el-col>
            <el-form-item :label="'审核状态'" prop="name">
              <el-input
                clearable
                v-model="form.name"
                :placeholder="'请输入'"
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="handleClose">{{'取消'}}</el-button>
        <el-button type="primary" @click="onSubmit('form')">{{'确认'}}</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import topBar from "@/components/topBar";
import * as api from "@/api/notice.js";
import { classifyUpdate, classifySave } from "@/api/product";
export default {
  name: "Bzpz",
  components: {
    topBar,
  },
  filters: {
    isAgree(val) {
      if (!val) {
        return '允许';
      } else {
        return '禁止';
      }
    },
  },
  data() {
    return {
      typeList: [
        {
          value: 0,
          label: '前台',
        },
        {
          value: 1,
          label: '后台',
        },
      ],
      digList: [
        {
          value: 0,
          label: '允许',
        },
        {
          value: 1,
          label: '禁止',
        },
      ],
      creationTime: [],
      creationTime1: [],
      creationTime2: [],
      select: {
        functionType: 2,
      },
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 50,
      },
      addOrEdit: "",
      total: 0,
      dialogVisible: false,
      loading:false,
      tableData: [],
      form: {
        name: "",
      },
      rules: {
        name: [{ required: true, message: '请输入规格类型', trigger: "blur" }],
      },
      webList: [],
      localList: [],
      popList: [],
      gradeList: [],
      stateList: [],
      moren: "/announcement/email",
      topList: [
        {
          name: "站内信",
          path: "/announcement/email",
        },

      ],
    };
  },
  mounted() {
    // 获取下拉
    this.getData();
    // 获取列表
    this.getDataList();
  },
  methods: {
    reset() {
      this.select = {
        functionType: 2,
      };
      this.creationTime = [];
      this.creationTime1 = [];
      this.creationTime2 = [];
      this.getDataList();
    },
    getData() {
      api.noticeWebsite().then((res) => {
        this.webList = res.data;
      });
      api.noticeLocation().then((res) => {
        this.localList = res.data;
      });
      api.noticePopup().then((res) => {
        this.popList = res.data;
      });
      api.getGradeRanglist().then((res) => {
        this.gradeList = res.data;
      });
      api.noticeState().then((res) => {
        this.stateList = res.data;
      });
    },
    changeTime(val) {
      this.select.startDate = val[0];
      this.select.endDate = val[1];
    },
    changeTime1(val) {
      this.select.startEffectDate = val[0];
      this.select.endEffectDate = val[1];
    },
    changeTime2(val) {
      this.select.startFinishtDate = val[0];
      this.select.endFinishtDate = val[1];
    },
    // 点击修改
    toFixed(id, index) {
      // this.addOrEdit = false
      // this.dialogVisible = true
      this.$router.push({
        path: "email/details",
        query: {
          pkId: id,
          type: index,
        },
      });
    },
    // 删除
    handleDelete(id) {
      this.$confirm('确认删除?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: "warning",
      }).then(() => {
        api.noticeDelete({ pkId: id }).then((res) => {
          this.getDataList();
        });
      });
    },
    onSubmit(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid) {
          let url = "";
          if (this.addOrEdit == true) {
            url = classifySave;
          } else {
            url = classifyUpdate;
          }
          url(this.form).then((res) => {
            if (res.code == 200) {
              this.$message({
                message: res.msg,
                type: "success",
              });
              this.dialogVisible = false;
              // 充值数据
              this.$refs[formName].resetFields();
              // 获取列表
              this.getDataList();
            }
          });
        } else {
          return false;
        }
      });
    },
    handleClose() {
      this.dialogVisible = false;
      this.$refs["form"].clearValidate();
      this.$refs["form"].resetFields();
    },
    openDig() {
      // this.$router.push({
      //   path: "email/details",
      // });
      this.$router.push({
        path: "noticeList/details",
        // query: {
        //   isAdmin: true,
        // },
      });
    },
    getDataList() {
      this.loading = true
      api
        .noticeMemberList(Object.assign({}, this.queryParams, this.select))
        .then((res) => {
          this.loading = false
          this.tableData = res.rows;
          this.total = res.total;
        });
    },
    handleSelectionChange(val) {},
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: "warning",
      })
        .then(function () {
          return api.exportClassIfy(queryParams);
        })
        .then((response) => {
          this.download(response);
        });
    },
    tableRowClassName({ row, rowIndex }) {
      if (rowIndex % 2 == 1) {
        return "warning-row";
      } else if (rowIndex % 2 == 0) {
        return "success-row";
      }
      return "";
    },
  },
};
</script>
<style scoped lang="scss">
::v-deep .el-table .warning-row {
  background: #f9f9f9;
}
.searchbtn {
  background: #c8161d;
  color: #ffffff;
}
::v-deep .el-table .success-row {
  background: #ffffff;
}
::v-deep .el-table thead {
  color: #000000;
}
::v-deep .el-select {
  width: 100%;
}
.uploadIcon ::v-deep .el-upload--picture-card {
  display: none !important; /* 上传按钮隐藏 */
}
.page {
  padding: 20px;
  background: #f9f9f9;
  font-size: 14px;
  .main {
    background: #ffffff;
    border-radius: 8px;
    // padding: 20px;
    box-shadow: 0px 2px 20px 0px rgba(238, 238, 238, 0.5);
    .maintop {
      display: flex;
      // padding: 10px 0px;
      justify-content: space-between;
      align-items: center;
      .mainbtn {
        .thebtn1 {
          background: #3181e5;
          color: #ffffff;
        }
        .thebtn2 {
          background: #ffad41;
          color: #ffffff;
        }
      }
      .maintitle {
        font-size: 10px;
        font-family: MicrosoftYaHei;
        color: #999999;
      }
    }
  }
  .tem {
    display: flex;
    align-items: center;
    justify-content: center;
    img {
      width: 28px;
      height: 20px;
      margin-right: 3px;
    }
  }
  .isRed {
    color: #ed1d25;
  }
  .isGreen {
    color: #1ab62b;
  }
  .bgImg {
    width: 48px;
    height: 48px;
  }
}
.openClose {
  text-align: right;
  margin-right: 10px;
  color: #3181e5;
}
::v-deep .el-date-editor.el-input,
.el-date-editor.el-input__inner {
  width: 100%;
}
</style>
